@@ -3,11 +3,9 @@
 from .core import CoreComponent
 from .commands import CommandsComponent
 from .mcp import MCPComponent
-from .hooks import HooksComponent
 
 __all__ = [
     'CoreComponent',
     'CommandsComponent', 
-    'MCPComponent',
-    'HooksComponent'
+    'MCPComponent'
 ]
\ No newline at end of file
